#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-protocol-xmpp
version:              0.5.2
visibility:           public
id:                   network-protocol-xmpp-0.5.2-BmRDLgIzROjLenhniFixWT
key:                  network-protocol-xmpp-0.5.2-BmRDLgIzROjLenhniFixWT
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  411c47f7673b0bbb71e1c4695f70f535
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.Handle Network.Protocol.XMPP.JID
    Network.Protocol.XMPP.Monad Network.Protocol.XMPP.Stanza
    Network.Protocol.XMPP.XML Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-protocol-xmpp-0.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-protocol-xmpp-0.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-protocol-xmpp-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-protocol-xmpp
hs-libraries:         HSnetwork-protocol-xmpp-0.5.2-BmRDLgIzROjLenhniFixWT
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    gnuidn-0.2.2-DnbCFNAfq4SL5RyNBkF95T
    gnutls-0.3.1-DfSYsbhT7aW4qO9vUdF2i5
    gsasl-0.3.7-BClaLdvuCdGBYnuLIBLUPC
    libxml-sax-0.7.6-6ml0QZEZFNI1hKWoe8c37A
    network-3.1.4.0-8HZ2mHT7KyE1ZVQfwLbJCE
    network-simple-0.4.5-GAhOyRXRsIMK2qsgF5F4Yw text-2.0.2
    transformers-0.6.1.0 xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

